@@ -588,8 +588,8 @@ class OKULARCORE_EXPORT Document : public QObject
             NextMatch,      ///< Search next match
             PreviousMatch,  ///< Search previous match
             AllDocument,    ///< Search complete document
-            GoogleAll,      ///< Search all words in google style
-            GoogleAny       ///< Search any words in google style
+            GoogleAll,      ///< Search complete document (all words in google style)
+            GoogleAny       ///< Search complete document (any words in google style)
         };
 
         /**
@@ -1117,7 +1117,7 @@ class OKULARCORE_EXPORT Document : public QObject
         Q_PRIVATE_SLOT( d, void slotTimedMemoryCheck() )
         Q_PRIVATE_SLOT( d, void sendGeneratorPixmapRequest() )
         Q_PRIVATE_SLOT( d, void rotationFinished( int page, Okular::Page *okularPage ) )
-        Q_PRIVATE_SLOT( d, void fontReadingProgress( int page ) )
+        Q_PRIVATE_SLOT( d, void slotFontReadingProgress( int page ) )
         Q_PRIVATE_SLOT( d, void fontReadingGotFont( const Okular::FontInfo& font ) )
         Q_PRIVATE_SLOT( d, void slotGeneratorConfigChanged( const QString& ) )
         Q_PRIVATE_SLOT( d, void refreshPixmaps( int ) )
