@@ -13,9 +13,11 @@
 
 class EPubGenerator : public Okular::TextDocumentGenerator
 {
+    Q_OBJECT
+    Q_INTERFACES( Okular::Generator )
  public:
   EPubGenerator( QObject *parent, const QVariantList &args );
-  ~EPubGenerator() {}
+  ~EPubGenerator();
 
   // [INHERITED] reparse configuration
   void addPages( KConfigDialog* dlg );
