@@ -21,10 +21,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
 #include <stdio.h>
 #include <sys/types.h>
 
-#include <kdebug.h>
+#include <QtCore/QDebug>
 
 #include "faxexpand.h"
-
+#include "fax_debug.h"
 //Uncomment this for verbose debug output
 //#define DEBUG_FAX
 #define verbose false
@@ -300,14 +300,14 @@ const char *StateNames[] = {
 	case S_Ext:							\
 	    *pa++ = lastx - a0;						\
 	    if (verbose)						\
-                kDebug() << "Line " << LineNum << ": extension code\n";\
+                qCDebug(FAX_LOG) << "Line " << LineNum << ": extension code\n";\
 	    SKIP_EOL;							\
 	    break;							\
 	case S_EOL:							\
 	    *pa++ = lastx - a0;						\
 	    NeedBits(4);						\
 	    if (GetBits(4) && verbose) /* already seen 7 zeros */	\
-                kDebug() << "Line " << LineNum << ": Bad EOL\n";        \
+                qCDebug(FAX_LOG) << "Line " << LineNum << ": Bad EOL\n";        \
 	    ClrBits(4);							\
 	    EOLcnt = 1;							\
 	    goto eolab;							\
@@ -337,13 +337,13 @@ static void
 unexpected(const char *what, int LineNum)
 {
     if (verbose)
-        kError() << "Line " << LineNum << ": Unexpected state in "
+        qCCritical(FAX_LOG) << "Line " << LineNum << ": Unexpected state in "
 		<< what << endl;
 }
 
 /* Expand tiff modified huffman data (g3-1d without EOLs) */
 void
-MHexpand(struct pagenode *pn, drawfunc df)
+MHexpand(pagenode *pn, drawfunc df)
 {
     int a0;			/* reference element */
     int lastx;			/* copy line width to register */
@@ -379,7 +379,7 @@ MHexpand(struct pagenode *pn, drawfunc df)
 	    SETVAL(0);
 	if (a0 != lastx) {
 	    if (verbose)
-                kWarning() << "Line " << LineNum << ": length is "
+                qCWarning(FAX_LOG) << "Line " << LineNum << ": length is "
 			<< a0 << " (expected "<< lastx << ")\n";
 	    while (a0 > lastx)
 		a0 -= *--pa;
@@ -396,7 +396,7 @@ MHexpand(struct pagenode *pn, drawfunc df)
 
 /* Expand group-3 1-dimensional data */
 void
-g31expand(struct pagenode *pn, drawfunc df)
+g31expand(pagenode *pn, drawfunc df)
 {
     int a0;			/* reference element */
     int lastx;			/* copy line width to register */
@@ -448,7 +448,7 @@ g31expand(struct pagenode *pn, drawfunc df)
 	    ClrBits(11);
 	}
         if (EOLcnt > 1 && EOLcnt != 6 && verbose) {
-            kError() << "Line " << LineNum << ": bad RTC (" << EOLcnt << " EOLs)\n";
+            qCCritical(FAX_LOG) << "Line " << LineNum << ": bad RTC (" << EOLcnt << " EOLs)\n";
         }
 	if (EOLcnt >= 6 || EndOfData(pn)) {
 	    free(runs);
@@ -463,7 +463,7 @@ g31expand(struct pagenode *pn, drawfunc df)
 	    SETVAL(0);
 	if (a0 != lastx) {
 	    if (verbose)
-                kWarning() << "Line " << LineNum << ": length is "
+                qCWarning(FAX_LOG) << "Line " << LineNum << ": length is "
 			<< a0 << " (expected "<< lastx << ")\n";
 	    while (a0 > lastx)
 		a0 -= *--pa;
@@ -480,7 +480,7 @@ g31expand(struct pagenode *pn, drawfunc df)
 
 /* Expand group-3 2-dimensional data */
 void
-g32expand(struct pagenode *pn, drawfunc df)
+g32expand(pagenode *pn, drawfunc df)
 {
     int RunLength;		/* Length of current run */
     int a0;			/* reference element */
@@ -539,13 +539,13 @@ g32expand(struct pagenode *pn, drawfunc df)
 	    ClrBits(11);
 	}
 	if (EOLcnt > 1 && EOLcnt != 6 && verbose)
-            kError() << "Line " << LineNum << ": bad RTC (" << EOLcnt << " EOLs)\n";
+            qCCritical(FAX_LOG) << "Line " << LineNum << ": bad RTC (" << EOLcnt << " EOLs)\n";
 	if (EOLcnt >= 6 || EndOfData(pn)) {
 	    free(run0);
 	    return;
 	}
 	if (LineNum == 0 && refline == 0 && verbose)
-            kDebug() << "First line is 2-D encoded\n";
+            qCDebug(FAX_LOG) << "First line is 2-D encoded\n";
 	RunLength = 0;
 	if (LineNum & 1) {
 	    pa = run1;
@@ -570,7 +570,7 @@ g32expand(struct pagenode *pn, drawfunc df)
 	    SETVAL(0);
 	if (a0 != lastx) {
 	    if (verbose)
-                kWarning() << "Line " << LineNum << ": length is "
+                qCWarning(FAX_LOG) << "Line " << LineNum << ": length is "
 			<< a0 << " (expected "<< lastx << ")\n";
 	    while (a0 > lastx)
 		a0 -= *--pa;
@@ -592,7 +592,7 @@ g32expand(struct pagenode *pn, drawfunc df)
 #undef eol2lab
 #define SKIP_EOL do {							\
     if (verbose)							\
-        kError() << "Line " << LineNum << ": G4 coding error\n";       \
+        qCCritical(FAX_LOG) << "Line " << LineNum << ": G4 coding error\n";       \
     free(run0);								\
     return;								\
 } while (0)
@@ -600,7 +600,7 @@ g32expand(struct pagenode *pn, drawfunc df)
 
 /* Expand group-4 data */
 void
-g4expand(struct pagenode *pn, drawfunc df)
+g4expand(pagenode *pn, drawfunc df)
 {
     int RunLength;		/* Length of current run */
     int a0;			/* reference element */
@@ -654,7 +654,7 @@ g4expand(struct pagenode *pn, drawfunc df)
     EOFB:
 	NeedBits(13);
 	if (GetBits(13) != 0x1001 && verbose)
-            kError() << "Bad RTC\n";
+            qCCritical(FAX_LOG) << "Bad RTC\n";
 	break;
     }
     free(run0);
@@ -717,7 +717,7 @@ static const unsigned char zerotab[256] = {
 
 /* count fax lines */
 int
-G3count(struct pagenode *pn, int twoD)
+G3count(pagenode *pn, int twoD)
 {
     t16bits *p = pn->data;
     t16bits *end = p + pn->length/sizeof(*p);
