@@ -17,11 +17,13 @@ namespace Txt
 {
     class Converter : public Okular::TextDocumentConverter
     {
+    Q_OBJECT
+
     public:
         Converter();
         ~Converter();
 
-        virtual QTextDocument *convert( const QString &fileName );
+        QTextDocument *convert( const QString &fileName ) Q_DECL_OVERRIDE;
     };
 }
 
