@@ -20,7 +20,7 @@ class QDoubleSpinBox;
 class QLabel;
 class QWidget;
 class KColorButton;
-class KIntNumInput;
+class QSpinBox;
 class KFontRequester;
 class AnnotationWidget;
 
@@ -30,7 +30,7 @@ class PixmapPreviewSelector
     Q_OBJECT
 
 public:
-    explicit PixmapPreviewSelector( QWidget * parent = 0 );
+    explicit PixmapPreviewSelector( QWidget * parent = Q_NULLPTR );
     virtual ~PixmapPreviewSelector();
 
     void setIcon( const QString& icon );
@@ -43,10 +43,10 @@ public:
 
     void setEditable( bool editable );
 
-signals:
+Q_SIGNALS:
     void iconChanged( const QString& );
 
-private slots:
+private Q_SLOTS:
     void iconComboChanged( const QString& icon );
 
 private:
@@ -82,7 +82,7 @@ public:
 
     virtual void applyChanges();
 
-signals:
+Q_SIGNALS:
     void dataChanged();
 
 protected:
@@ -95,7 +95,7 @@ protected:
     QWidget * m_appearanceWidget;
     QWidget * m_extraWidget;
     KColorButton *m_colorBn;
-    KIntNumInput *m_opacity;
+    QSpinBox *m_opacity;
 };
 
 class TextAnnotationWidget
@@ -104,12 +104,12 @@ class TextAnnotationWidget
     Q_OBJECT
 
 public:
-    TextAnnotationWidget( Okular::Annotation * ann );
+    explicit TextAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::TextAnnotation * m_textAnn;
@@ -125,12 +125,12 @@ class StampAnnotationWidget
     Q_OBJECT
 
 public:
-    StampAnnotationWidget( Okular::Annotation * ann );
+    explicit StampAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::StampAnnotation * m_stampAnn;
@@ -143,12 +143,12 @@ class LineAnnotationWidget
     Q_OBJECT
 
 public:
-    LineAnnotationWidget( Okular::Annotation * ann );
+    explicit LineAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    virtual QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::LineAnnotation * m_lineAnn;
@@ -166,12 +166,12 @@ class HighlightAnnotationWidget
     Q_OBJECT
 
 public:
-    HighlightAnnotationWidget( Okular::Annotation * ann );
+    explicit HighlightAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::HighlightAnnotation * m_hlAnn;
@@ -184,12 +184,12 @@ class GeomAnnotationWidget
     Q_OBJECT
 
 public:
-    GeomAnnotationWidget( Okular::Annotation * ann );
+    explicit GeomAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::GeomAnnotation * m_geomAnn;
@@ -205,13 +205,13 @@ class FileAttachmentAnnotationWidget
     Q_OBJECT
 
 public:
-    FileAttachmentAnnotationWidget( Okular::Annotation * ann );
+    explicit FileAttachmentAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
-    virtual QWidget * createExtraWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
+    QWidget * createExtraWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::FileAttachmentAnnotation * m_attachAnn;
@@ -224,12 +224,12 @@ class CaretAnnotationWidget
     Q_OBJECT
 
 public:
-    CaretAnnotationWidget( Okular::Annotation * ann );
+    explicit CaretAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::CaretAnnotation * m_caretAnn;
@@ -242,12 +242,12 @@ class InkAnnotationWidget
     Q_OBJECT
 
 public:
-    InkAnnotationWidget( Okular::Annotation * ann );
+    explicit InkAnnotationWidget( Okular::Annotation * ann );
 
-    virtual void applyChanges();
+    void applyChanges() Q_DECL_OVERRIDE;
 
 protected:
-    virtual QWidget * createStyleWidget();
+    QWidget * createStyleWidget() Q_DECL_OVERRIDE;
 
 private:
     Okular::InkAnnotation * m_inkAnn;
