@@ -61,7 +61,7 @@ class FormWidgetsController : public QObject
         bool canUndo();
         bool canRedo();
 
-    signals:
+    Q_SIGNALS:
         void changed( int pageNumber );
         void requestUndo();
         void requestRedo();
@@ -110,7 +110,7 @@ class FormWidgetsController : public QObject
 
         void action( Okular::Action *action );
 
-    private slots:
+    private Q_SLOTS:
         void slotButtonClicked( QAbstractButton *button );
         void slotFormButtonsChangedByUndoRedo( int pageNumber,
                                                const QList< Okular::FormFieldButton* > & formButtons );
@@ -132,7 +132,7 @@ class FormWidgetsController : public QObject
 class FormWidgetFactory
 {
     public:
-        static FormWidgetIface * createWidget( Okular::FormField * ff, QWidget * parent = 0 );
+        static FormWidgetIface * createWidget( Okular::FormField * ff, QWidget * parent = Q_NULLPTR );
 };
 
 
@@ -170,9 +170,9 @@ class PushButtonEdit : public QPushButton, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit PushButtonEdit( Okular::FormFieldButton * button, QWidget * parent = 0 );
+        explicit PushButtonEdit( Okular::FormFieldButton * button, QWidget * parent = Q_NULLPTR );
 
-    private slots:
+    private Q_SLOTS:
         void slotClicked();
 
     private:
@@ -184,13 +184,13 @@ class CheckBoxEdit : public QCheckBox, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit CheckBoxEdit( Okular::FormFieldButton * button, QWidget * parent = 0 );
+        explicit CheckBoxEdit( Okular::FormFieldButton * button, QWidget * parent = Q_NULLPTR );
 
         // reimplemented from FormWidgetIface
         void setFormWidgetsController( FormWidgetsController *controller );
         QAbstractButton* button();
 
-    private slots:
+    private Q_SLOTS:
         void slotStateChanged( int state );
 
     private:
@@ -202,7 +202,7 @@ class RadioButtonEdit : public QRadioButton, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit RadioButtonEdit( Okular::FormFieldButton * button, QWidget * parent = 0 );
+        explicit RadioButtonEdit( Okular::FormFieldButton * button, QWidget * parent = Q_NULLPTR );
 
         // reimplemented from FormWidgetIface
         void setFormWidgetsController( FormWidgetsController *controller );
@@ -217,19 +217,19 @@ class FormLineEdit : public QLineEdit, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit FormLineEdit( Okular::FormFieldText * text, QWidget * parent = 0 );
+        explicit FormLineEdit( Okular::FormFieldText * text, QWidget * parent = Q_NULLPTR );
         void setFormWidgetsController( FormWidgetsController *controller );
         virtual bool event ( QEvent * e );
         virtual void contextMenuEvent( QContextMenuEvent* event );
 
 
-    public slots:
+    public Q_SLOTS:
         void slotHandleTextChangedByUndoRedo( int pageNumber,
                                               Okular::FormFieldText* textForm,
                                               const QString & contents,
                                               int cursorPos,
                                               int anchorPos );
-    private slots:
+    private Q_SLOTS:
         void slotChanged();
 
     private:
@@ -243,12 +243,12 @@ class TextAreaEdit : public KTextEdit, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit TextAreaEdit( Okular::FormFieldText * text, QWidget * parent = 0 );
+        explicit TextAreaEdit( Okular::FormFieldText * text, QWidget * parent = Q_NULLPTR );
         void setFormWidgetsController( FormWidgetsController *controller );
         virtual bool event ( QEvent * e );
 
 
-    public slots:
+    public Q_SLOTS:
         void slotHandleTextChangedByUndoRedo( int pageNumber,
                                               Okular::FormFieldText * textForm,
                                               const QString & contents,
@@ -256,7 +256,7 @@ class TextAreaEdit : public KTextEdit, public FormWidgetIface
                                               int anchorPos );
         void slotUpdateUndoAndRedoInContextMenu( QMenu* menu );
 
-    private slots:
+    private Q_SLOTS:
         void slotChanged();
 
     private:
@@ -271,14 +271,14 @@ class FileEdit : public KUrlRequester, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit FileEdit( Okular::FormFieldText * text, QWidget * parent = 0 );
+        explicit FileEdit( Okular::FormFieldText * text, QWidget * parent = Q_NULLPTR );
         void setFormWidgetsController( FormWidgetsController *controller );
 
     protected:
         bool eventFilter( QObject *obj, QEvent *event );
 
 
-    private slots:
+    private Q_SLOTS:
         void slotChanged();
         void slotHandleFileChangedByUndoRedo( int pageNumber,
                                               Okular::FormFieldText * form,
@@ -297,10 +297,10 @@ class ListEdit : public QListWidget, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit ListEdit( Okular::FormFieldChoice * choice, QWidget * parent = 0 );
+        explicit ListEdit( Okular::FormFieldChoice * choice, QWidget * parent = Q_NULLPTR );
         void setFormWidgetsController( FormWidgetsController *controller );
 
-    private slots:
+    private Q_SLOTS:
         void slotSelectionChanged();
         void slotHandleFormListChangedByUndoRedo( int pageNumber,
                                                   Okular::FormFieldChoice * listForm,
@@ -316,12 +316,12 @@ class ComboEdit : public QComboBox, public FormWidgetIface
     Q_OBJECT
 
     public:
-        explicit ComboEdit( Okular::FormFieldChoice * choice, QWidget * parent = 0 );
+        explicit ComboEdit( Okular::FormFieldChoice * choice, QWidget * parent = Q_NULLPTR );
         void setFormWidgetsController( FormWidgetsController *controller );
         virtual bool event ( QEvent * e );
         virtual void contextMenuEvent( QContextMenuEvent* event );
 
-    private slots:
+    private Q_SLOTS:
         void slotValueChanged();
         void slotHandleFormComboChangedByUndoRedo( int pageNumber,
                                                    Okular::FormFieldChoice * comboForm,
