@@ -16,7 +16,6 @@
 #include <qhash.h>
 #include <qtoolbutton.h>
 
-#include <KIcon>
 
 #include "core/area.h"
 
@@ -102,6 +101,8 @@ class PageViewItem
  */
 class PageViewMessage : public QWidget
 {
+    Q_OBJECT
+
     public:
         PageViewMessage( QWidget * parent );
 
@@ -109,9 +110,9 @@ class PageViewMessage : public QWidget
         void display( const QString & message, const QString & details = QString(), Icon icon = Info, int durationMs = 4000 );
 
     protected:
-        bool eventFilter(QObject * obj, QEvent * event );
-        void paintEvent( QPaintEvent * e );
-        void mousePressEvent( QMouseEvent * e );
+        bool eventFilter(QObject * obj, QEvent * event ) Q_DECL_OVERRIDE;
+        void paintEvent( QPaintEvent * e ) Q_DECL_OVERRIDE;
+        void mousePressEvent( QMouseEvent * e ) Q_DECL_OVERRIDE;
 
     private:
         QRect computeTextRect( const QString & message, int extra_width ) const;
@@ -148,11 +149,11 @@ class ToolBarButton : public QToolButton
         int buttonID() const { return m_id; }
         bool isText() const { return m_isText; }
 
-    signals:
+    Q_SIGNALS:
         void buttonDoubleClicked( int buttonID );
 
     protected:
-        void mouseDoubleClickEvent( QMouseEvent * event );
+        void mouseDoubleClickEvent( QMouseEvent * event ) Q_DECL_OVERRIDE;
 
     private:
         int m_id;
@@ -190,7 +191,7 @@ class PageViewToolBar : public QWidget
 
         // query properties
 
-    signals:
+    Q_SIGNALS:
         // the tool 'toolID' has been selected
         void toolSelected( int toolID );
         // orientation has been changed
@@ -200,18 +201,18 @@ class PageViewToolBar : public QWidget
 
     protected:
         // handle widget events { anchor_resize, paint, animation, drag }
-        bool eventFilter( QObject * o, QEvent * e );
-        void paintEvent( QPaintEvent * );
-        void mousePressEvent( QMouseEvent * e );
-        void mouseMoveEvent( QMouseEvent * e );
-        void mouseReleaseEvent( QMouseEvent * e );
+        bool eventFilter( QObject * o, QEvent * e ) Q_DECL_OVERRIDE;
+        void paintEvent( QPaintEvent * ) Q_DECL_OVERRIDE;
+        void mousePressEvent( QMouseEvent * e ) Q_DECL_OVERRIDE;
+        void mouseMoveEvent( QMouseEvent * e ) Q_DECL_OVERRIDE;
+        void mouseReleaseEvent( QMouseEvent * e ) Q_DECL_OVERRIDE;
 
     private:
         // private variables
         friend class ToolBarPrivate;
         class ToolBarPrivate * d;
 
-    private slots:
+    private Q_SLOTS:
         void slotAnimate();
         void slotButtonClicked();
 };
