@@ -10,13 +10,14 @@
 #include "presentationwidget.h"
 
 // qt/kde includes
+#include <QtCore/qloggingcategory.h>
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusReply>
 
 #include <qevent.h>
 #include <qfontmetrics.h>
-#include <kicon.h>
+#include <QIcon>
 #include <qtimer.h>
 #include <qimage.h>
 #include <qlabel.h>
@@ -31,17 +32,19 @@
 #include <kcursor.h>
 #include <krandom.h>
 #include <qtoolbar.h>
-#include <kaction.h>
+#include <qaction.h>
 #include <kactioncollection.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kselectaction.h>
-#include <kshortcut.h>
-#include <kdialog.h>
+#include <QDialog>
 
-#include <Solid/PowerManagement>
+#ifdef Q_OS_LINUX
+#include <QDBusUnixFileDescriptor>
+#include <unistd.h> // For ::close() for sleep inhibition
+#endif
 
 // system includes
 #include <stdlib.h>
@@ -49,6 +52,8 @@
 
 // local includes
 #include "annotationtools.h"
+#include "debug_ui.h"
+#include "drawingtoolactions.h"
 #include "guiutils.h"
 #include "pagepainter.h"
 #include "presentationsearchbar.h"
@@ -110,19 +115,21 @@ struct PresentationFrame
 // background is not automatically filled
 class PresentationToolBar : public QToolBar
 {
+    Q_OBJECT
+
     public:
-        PresentationToolBar( QWidget * parent = 0 )
+        PresentationToolBar( QWidget * parent = Q_NULLPTR )
             : QToolBar( parent )
         {}
 
     protected:
-        void mousePressEvent( QMouseEvent * e )
+        void mousePressEvent( QMouseEvent * e ) override
         {
             QToolBar::mousePressEvent( e );
             e->accept();
         }
 
-        void mouseReleaseEvent( QMouseEvent * e )
+        void mouseReleaseEvent( QMouseEvent * e ) override
         {
             QToolBar::mouseReleaseEvent( e );
             e->accept();
@@ -130,9 +137,10 @@ class PresentationToolBar : public QToolBar
 };
 
 
-PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc, KActionCollection * collection )
+PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc, DrawingToolActions * drawingToolActions, KActionCollection * collection )
     : QWidget( 0 /* must be null, to have an independent widget */, Qt::FramelessWindowHint ),
     m_pressedLink( 0 ), m_handCursor( false ), m_drawingEngine( 0 ),
+    m_screenInhibitCookie(0), m_sleepInhibitCookie(0),
     m_parentWidget( parent ),
     m_document( doc ), m_frameIndex( -1 ), m_topBar( 0 ), m_pagesEdit( 0 ), m_searchBar( 0 ),
     m_ac( collection ), m_screenSelect( 0 ), m_isSetup( false ), m_blockNotifications( false ), m_inBlackScreenMode( false ),
@@ -142,22 +150,22 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     Q_UNUSED( parent )
     setAttribute( Qt::WA_DeleteOnClose );
     setAttribute( Qt::WA_OpaquePaintEvent );
-    setObjectName( QLatin1String( "presentationWidget" ) );
-    QString caption = doc->metaData( "DocumentTitle" ).toString();
+    setObjectName( QStringLiteral( "presentationWidget" ) );
+    QString caption = doc->metaData( QStringLiteral("DocumentTitle") ).toString();
     if ( caption.trimmed().isEmpty() )
         caption = doc->currentDocument().fileName();
     caption = i18nc( "[document title/filename] – Presentation", "%1 – Presentation", caption );
-    setWindowTitle( KDialog::makeStandardCaption( caption ) );
+    setWindowTitle( caption );
 
     m_width = -1;
     m_screen = -2;
 
     // create top toolbar
     m_topBar = new PresentationToolBar( this );
-    m_topBar->setObjectName( QLatin1String( "presentationBar" ) );
+    m_topBar->setObjectName( QStringLiteral( "presentationBar" ) );
     m_topBar->setMovable( false );
     m_topBar->layout()->setMargin(0);
-    m_topBar->addAction( KIcon( layoutDirection() == Qt::RightToLeft ? "go-next" : "go-previous" ), i18n( "Previous Page" ), this, SLOT(slotPrevPage()) );
+    m_topBar->addAction( QIcon::fromTheme( layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-next") : QStringLiteral("go-previous") ), i18n( "Previous Page" ), this, SLOT(slotPrevPage()) );
     m_pagesEdit = new KLineEdit( m_topBar );
     QSizePolicy sp = m_pagesEdit->sizePolicy();
     sp.setHorizontalPolicy( QSizePolicy::Minimum );
@@ -172,31 +180,36 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     QLabel *pagesLabel = new QLabel( m_topBar );
     pagesLabel->setText( QLatin1String( " / " ) + QString::number( m_document->pages() ) + QLatin1String( " " ) );
     m_topBar->addWidget( pagesLabel );
-    connect( m_pagesEdit, SIGNAL(returnPressed()), this, SLOT(slotPageChanged()) );
-    m_topBar->addAction( KIcon( layoutDirection() == Qt::RightToLeft ? "go-previous" : "go-next" ), i18n( "Next Page" ), this, SLOT(slotNextPage()) );
+    connect(m_pagesEdit, &QLineEdit::returnPressed, this, &PresentationWidget::slotPageChanged);
+    m_topBar->addAction( QIcon::fromTheme( layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-previous") : QStringLiteral("go-next") ), i18n( "Next Page" ), this, SLOT(slotNextPage()) );
     m_topBar->addSeparator();
-    QAction *playPauseAct = collection->action( "presentation_play_pause" );
+    QAction *playPauseAct = collection->action( QStringLiteral("presentation_play_pause") );
     playPauseAct->setEnabled( true );
-    connect( playPauseAct, SIGNAL(triggered()), SLOT(slotTogglePlayPause()) );
+    connect(playPauseAct, &QAction::triggered, this, &PresentationWidget::slotTogglePlayPause);
     m_topBar->addAction( playPauseAct );
     setPlayPauseIcon();
     addAction( playPauseAct );
     m_topBar->addSeparator();
-    QAction *drawingAct = collection->action( "presentation_drawing_mode" );
-    connect( drawingAct, SIGNAL(toggled(bool)), SLOT(togglePencilMode(bool)) );
-    drawingAct->setEnabled( true );
-    m_topBar->addAction( drawingAct );
-    addAction( drawingAct );
-    QAction *eraseDrawingAct = collection->action( "presentation_erase_drawings" );
+    QAction *eraseDrawingAct = collection->action( QStringLiteral("presentation_erase_drawings") );
     eraseDrawingAct->setEnabled( true );
-    connect( eraseDrawingAct, SIGNAL(triggered()), SLOT(clearDrawings()) );
+    connect(eraseDrawingAct, &QAction::triggered, this, &PresentationWidget::clearDrawings);
     m_topBar->addAction( eraseDrawingAct );
     addAction( eraseDrawingAct );
+
+    foreach(QAction *action, drawingToolActions->actions())
+    {
+        action->setEnabled( true );
+        m_topBar->addAction( action );
+        addAction( action );
+    }
+    connect( drawingToolActions, &DrawingToolActions::changeEngine, this, &PresentationWidget::slotChangeDrawingToolEngine );
+    connect( drawingToolActions, &DrawingToolActions::actionsRecreated, this, &PresentationWidget::slotAddDrawingToolActions );
+
     QDesktopWidget *desktop = QApplication::desktop();
     if ( desktop->numScreens() > 1 )
     {
         m_topBar->addSeparator();
-        m_screenSelect = new KSelectAction( KIcon( "video-display" ), i18n( "Switch Screen" ), m_topBar );
+        m_screenSelect = new KSelectAction( QIcon::fromTheme( QStringLiteral("video-display") ), i18n( "Switch Screen" ), m_topBar );
         m_screenSelect->setToolBarMode( KSelectAction::MenuMode );
         m_screenSelect->setToolButtonPopupMode( QToolButton::InstantPopup );
         m_topBar->addAction( m_screenSelect );
@@ -210,7 +223,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     QWidget *spacer = new QWidget( m_topBar );
     spacer->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::MinimumExpanding );
     m_topBar->addWidget( spacer );
-    m_topBar->addAction( KIcon( "application-exit" ), i18n( "Exit Presentation Mode" ), this, SLOT(close()) );
+    m_topBar->addAction( QIcon::fromTheme( QStringLiteral("application-exit") ), i18n( "Exit Presentation Mode" ), this, SLOT(close()) );
     m_topBar->setAutoFillBackground( true );
     showTopBar( false );
     // change topbar background color
@@ -224,16 +237,16 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     setContextMenuPolicy( Qt::PreventContextMenu );
     m_transitionTimer = new QTimer( this );
     m_transitionTimer->setSingleShot( true );
-    connect( m_transitionTimer, SIGNAL(timeout()), this, SLOT(slotTransitionStep()) );
+    connect(m_transitionTimer, &QTimer::timeout, this, &PresentationWidget::slotTransitionStep);
     m_overlayHideTimer = new QTimer( this );
     m_overlayHideTimer->setSingleShot( true );
-    connect( m_overlayHideTimer, SIGNAL(timeout()), this, SLOT(slotHideOverlay()) );
-    m_nextPageTimer = new QTimer( this ); 
+    connect(m_overlayHideTimer, &QTimer::timeout, this, &PresentationWidget::slotHideOverlay);
+    m_nextPageTimer = new QTimer( this );
     m_nextPageTimer->setSingleShot( true );
-    connect( m_nextPageTimer, SIGNAL(timeout()), this, SLOT(slotNextPage()) ); 
+    connect(m_nextPageTimer, &QTimer::timeout, this, &PresentationWidget::slotNextPage);
 
-    connect( m_document, SIGNAL(processMovieAction(const Okular::MovieAction*)), this, SLOT(slotProcessMovieAction(const Okular::MovieAction*)) );
-    connect( m_document, SIGNAL(processRenditionAction(const Okular::RenditionAction*)), this, SLOT(slotProcessRenditionAction(const Okular::RenditionAction*)) );
+    connect(m_document, &Okular::Document::processMovieAction, this, &PresentationWidget::slotProcessMovieAction);
+    connect(m_document, &Okular::Document::processRenditionAction, this, &PresentationWidget::slotProcessRenditionAction);
 
     // handle cursor appearance as specified in configuration
     if ( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::HiddenDelay )
@@ -253,7 +266,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
 
     show();
 
-    QTimer::singleShot( 0, this, SLOT(slotDelayedEvents()) );
+    QTimer::singleShot( 0, this, &PresentationWidget::slotDelayedEvents );
 
     // setFocus() so KCursor::setAutoHideCursor() goes into effect if it's enabled
     setFocus( Qt::OtherFocusReason );
@@ -276,20 +289,12 @@ PresentationWidget::~PresentationWidget()
     // remove this widget from document observer
     m_document->removeObserver( this );
 
-    QAction *drawingAct = m_ac->action( "presentation_drawing_mode" );
-    disconnect( drawingAct, 0, this, 0 );
-    drawingAct->setChecked( false );
-    drawingAct->setEnabled( false );
+    foreach( QAction *action, m_topBar->actions() )
+    {
+        action->setChecked( false );
+        action->setEnabled( false );
+    }
 
-    QAction *eraseDrawingAct = m_ac->action( "presentation_erase_drawings" );
-    eraseDrawingAct->setEnabled( false );
-
-    QAction *playPauseAction = m_ac->action( "presentation_play_pause" );
-    playPauseAction->setEnabled( false );
-
-    QAction *blackScreenAct = m_ac->action( "switch_blackscreen_mode" );
-    blackScreenAct->setChecked( false );
-    blackScreenAct->setEnabled( false );
     delete m_drawingEngine;
 
     // delete frames
@@ -311,7 +316,7 @@ void PresentationWidget::notifySetup( const QVector< Okular::Page * > & pageSet,
     for ( ; fIt != fEnd; ++fIt )
         delete *fIt;
     if ( !m_frames.isEmpty() )
-        kWarning() << "Frames setup changed while a Presentation is in progress.";
+        qCWarning(OkularUiDebug) << "Frames setup changed while a Presentation is in progress.";
     m_frames.clear();
 
     // create the new frames
@@ -333,6 +338,15 @@ void PresentationWidget::notifySetup( const QVector< Okular::Page * > & pageSet,
                 frame->videoWidgets.insert( movieAnn->movie(), vw );
                 vw->pageInitialized();
             }
+            else if ( a->subType() == Okular::Annotation::ARichMedia )
+            {
+                Okular::RichMediaAnnotation * richMediaAnn = static_cast< Okular::RichMediaAnnotation * >( a );
+                if ( richMediaAnn->movie() ) {
+                    VideoWidget * vw = new VideoWidget( richMediaAnn, richMediaAnn->movie(), m_document, this );
+                    frame->videoWidgets.insert( richMediaAnn->movie(), vw );
+                    vw->pageInitialized();
+                }
+            }
             else if ( a->subType() == Okular::Annotation::AScreen )
             {
                 const Okular::ScreenAnnotation * screenAnn = static_cast< Okular::ScreenAnnotation * >( a );
@@ -483,30 +497,30 @@ bool PresentationWidget::canUnloadPixmap( int pageNumber ) const
 
 void PresentationWidget::setupActions()
 {
-    addAction( m_ac->action( "first_page" ) );
-    addAction( m_ac->action( "last_page" ) );
-    addAction( m_ac->action( KStandardAction::name( KStandardAction::Prior ) ) );
-    addAction( m_ac->action( KStandardAction::name( KStandardAction::Next ) ) );
-    addAction( m_ac->action( KStandardAction::name( KStandardAction::DocumentBack ) ) );
-    addAction( m_ac->action( KStandardAction::name( KStandardAction::DocumentForward ) ) );
+    addAction( m_ac->action( QStringLiteral("first_page") ) );
+    addAction( m_ac->action( QStringLiteral("last_page") ) );
+    addAction( m_ac->action( QString::fromLocal8Bit(KStandardAction::name( KStandardAction::Prior ) ) ) );
+    addAction( m_ac->action( QString::fromLocal8Bit(KStandardAction::name( KStandardAction::Next ) ) ) );
+    addAction( m_ac->action( QString::fromLocal8Bit(KStandardAction::name( KStandardAction::DocumentBack ) ) ) );
+    addAction( m_ac->action( QString::fromLocal8Bit(KStandardAction::name( KStandardAction::DocumentForward ) ) ) );
 
-    QAction *action = m_ac->action( "switch_blackscreen_mode" );
-    connect( action, SIGNAL(toggled(bool)), SLOT(toggleBlackScreenMode(bool)) );
+    QAction *action = m_ac->action( QStringLiteral("switch_blackscreen_mode") );
+    connect(action, &QAction::toggled, this, &PresentationWidget::toggleBlackScreenMode);
     action->setEnabled( true );
     addAction( action );
 }
 
 void PresentationWidget::setPlayPauseIcon()
 {
-    QAction *playPauseAction = m_ac->action( "presentation_play_pause" );
+    QAction *playPauseAction = m_ac->action( QStringLiteral("presentation_play_pause") );
     if ( m_advanceSlides )
     {
-       playPauseAction->setIcon( KIcon( "media-playback-pause" ) );
+       playPauseAction->setIcon( QIcon::fromTheme( QStringLiteral("media-playback-pause") ) );
        playPauseAction->setToolTip( i18nc( "For Presentation", "Pause" ) );
     }
     else
     {
-       playPauseAction->setIcon( KIcon( "media-playback-start" ) );
+       playPauseAction->setIcon( QIcon::fromTheme( QStringLiteral("media-playback-start") ) );
        playPauseAction->setToolTip( i18nc( "For Presentation", "Play" ) );
     }
 }
@@ -627,6 +641,15 @@ void PresentationWidget::mousePressEvent( QMouseEvent * e )
                 vw->play();
                 return;
             }
+            else if ( annotation->subType() == Okular::Annotation::ARichMedia )
+            {
+                const Okular::RichMediaAnnotation *richMediaAnnotation = static_cast<const Okular::RichMediaAnnotation*>( annotation );
+
+                VideoWidget *vw = m_frames[ m_frameIndex ]->videoWidgets.value( richMediaAnnotation->movie() );
+                vw->show();
+                vw->play();
+                return;
+            }
             else if ( annotation->subType() == Okular::Annotation::AScreen )
             {
                 m_document->processAction( static_cast<const Okular::ScreenAnnotation*>( annotation )->action() );
@@ -724,7 +747,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
         m_width = width();
         m_height = height();
 
-        connect( m_document, SIGNAL(linkFind()), this, SLOT(slotFind()) );
+        connect(m_document, &Okular::Document::linkFind, this, &PresentationWidget::slotFind);
 
         // register this observer in document. events will come immediately
         m_document->addObserver( this );
@@ -735,7 +758,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
     }
 
     // check painting rect consistancy
-    QRect r = pe->rect().intersect( QRect( QPoint( 0, 0 ), geometry().size() ) );
+    QRect r = pe->rect().intersected( QRect( QPoint( 0, 0 ), geometry().size() ) );
     if ( r.isNull() )
         return;
 
@@ -766,7 +789,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
             pixPainter.drawPixmap( QPoint(0,0), m_lastRenderedPixmap, r );
 
             // then blend the overlay (a piece of) over the background
-            QRect ovr = m_overlayGeometry.intersect( r );
+            QRect ovr = m_overlayGeometry.intersected( r );
             pixPainter.drawPixmap( ovr.left() - r.left(), ovr.top() - r.top(),
                 m_lastRenderedOverlay, ovr.left() - m_overlayGeometry.left(),
                 ovr.top() - m_overlayGeometry.top(), ovr.width(), ovr.height() );
@@ -783,16 +806,23 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
     // paint drawings
     if ( m_frameIndex != -1 )
     {
-        const QRect & geom = m_frames[ m_frameIndex ]->geometry;
         painter.save();
-        painter.translate( geom.topLeft() );
-        painter.setRenderHints( QPainter::Antialiasing );
 
+        const QRect & geom = m_frames[ m_frameIndex ]->geometry;
+
+        QPixmap pm( geom.size() );
+        pm.fill( Qt::transparent );
+        QPainter pmPainter( &pm );
+
+        pmPainter.setRenderHints( QPainter::Antialiasing );
         foreach ( const SmoothPath &drawing, m_frames[ m_frameIndex ]->drawings )
-            drawing.paint( &painter, geom.width(), geom.height() );
+            drawing.paint( &pmPainter, geom.width(), geom.height() );
 
         if ( m_drawingEngine && m_drawingRect.intersects( pe->rect() ) )
-            m_drawingEngine->paint( &painter, geom.width(), geom.height(), m_drawingRect.intersect( pe->rect() ) );
+            m_drawingEngine->paint( &pmPainter, geom.width(), geom.height(), m_drawingRect.intersected( pe->rect() ) );
+
+        painter.setRenderHints( QPainter::Antialiasing );
+        painter.drawPixmap( geom.topLeft() , pm );
 
         painter.restore();
     }
@@ -801,7 +831,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
 
 void PresentationWidget::resizeEvent( QResizeEvent *re )
 {
-    // kDebug() << re->oldSize() << "=>" << re->size();
+    // qCDebug(OkularUiDebug) << re->oldSize() << "=>" << re->size();
     if ( re->oldSize() == QSize( -1, -1 ) )
         return;
 
@@ -876,6 +906,7 @@ void PresentationWidget::testCursorOnLink( int x, int y )
 
     const bool needsHandCursor = ( ( link != 0 ) ||
                                  ( ( annotation != 0 ) && ( annotation->subType() == Okular::Annotation::AMovie ) ) ||
+                                 ( ( annotation != 0 ) && ( annotation->subType() == Okular::Annotation::ARichMedia ) ) ||
                                  ( ( annotation != 0 ) && ( annotation->subType() == Okular::Annotation::AScreen ) && ( GuiUtils::renditionMovieFromScreenAnnotation( static_cast< const Okular::ScreenAnnotation * >( annotation ) ) != 0 ) ) );
 
     // only react on changes (in/out from a link)
@@ -993,7 +1024,7 @@ void PresentationWidget::generateIntroPage( QPainter & p )
     }
 
     // draw okular logo in the four corners
-    QPixmap logo = DesktopIcon( "okular", 64 );
+    QPixmap logo = DesktopIcon( QStringLiteral("okular"), 64 );
     if ( !logo.isNull() )
     {
         p.drawPixmap( 5, 5, logo );
@@ -1048,7 +1079,7 @@ void PresentationWidget::generateContentsPage( int pageNum, QPainter & p )
 
     // fill unpainted areas with background color
     QRegion unpainted( QRect( 0, 0, m_width, m_height ) );
-    QVector<QRect> rects = unpainted.subtract( frame->geometry ).rects();
+    QVector<QRect> rects = unpainted.subtracted( frame->geometry ).rects();
     for ( int i = 0; i < rects.count(); i++ )
     {
         const QRect & r = rects[i];
@@ -1237,8 +1268,8 @@ QRect PresentationWidget::routeMouseDrawingEvent( QMouseEvent * e )
         // manually disable and re-enable the pencil mode, so we can do
         // cleaning of the actual drawer and create a new one just after
         // that - that gives continuous drawing
-        togglePencilMode( false );
-        togglePencilMode( true );
+        slotChangeDrawingToolEngine( QDomElement() );
+        slotChangeDrawingToolEngine( m_currentDrawingToolElement );
 
         // schedule repaint
         update();
@@ -1287,7 +1318,7 @@ void PresentationWidget::recalcGeometry()
         Okular::Settings::setSlidesScreen( -2 );
     }
     const QRect screenGeom = desktop->screenGeometry( screen );
-    // kDebug() << screen << "=>" << screenGeom;
+    // qCDebug(OkularUiDebug) << screen << "=>" << screenGeom;
     m_screen = screen;
     setGeometry( screenGeom );
 }
@@ -1482,18 +1513,18 @@ void PresentationWidget::slotDelayedEvents()
     if ( m_screenSelect )
     {
         m_screenSelect->setCurrentItem( m_screen );
-        connect( m_screenSelect->selectableActionGroup(), SIGNAL(triggered(QAction*)),
-                 this, SLOT(chooseScreen(QAction*)) );
+        connect( m_screenSelect->selectableActionGroup(), &QActionGroup::triggered,
+                 this, &PresentationWidget::chooseScreen );
     }
 
     // show widget and take control
     show();
     setWindowState( windowState() | Qt::WindowFullScreen );
 
-    connect( QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(screenResized(int)) );
+    connect( QApplication::desktop(), &QDesktopWidget::resized, this, &PresentationWidget::screenResized );
 
   // inform user on how to exit from presentation mode
-  KMessageBox::information( this, i18n("There are two ways of exiting presentation mode, you can press either ESC key or click with the quit button that appears when placing the mouse in the top-right corner. Of course you can cycle windows (Alt+TAB by default)"), QString(), "presentationInfo" );
+  KMessageBox::information( this, i18n("There are two ways of exiting presentation mode, you can press either ESC key or click with the quit button that appears when placing the mouse in the top-right corner. Of course you can cycle windows (Alt+TAB by default)"), QString(), QStringLiteral("presentationInfo") );
 }
 
 void PresentationWidget::slotPageChanged()
@@ -1506,31 +1537,31 @@ void PresentationWidget::slotPageChanged()
     changePage( p - 1 );
 }
 
-void PresentationWidget::togglePencilMode( bool on )
+void PresentationWidget::slotChangeDrawingToolEngine( const QDomElement &element )
 {
-    if ( on )
-    {
-        QString colorstring = Okular::Settings::slidesPencilColor().name();
-        // FIXME this should not be recreated every time
-        QDomDocument doc( "engine" );
-        QDomElement root = doc.createElement( "engine" );
-        root.setAttribute( "color", colorstring );
-        doc.appendChild( root );
-        QDomElement annElem = doc.createElement( "annotation" );
-        root.appendChild( annElem );
-        annElem.setAttribute( "type", "Ink" );
-        annElem.setAttribute( "color", colorstring );
-        annElem.setAttribute( "width", "2" );
-        m_drawingEngine = new SmoothPathEngine( root );
-        setCursor( KCursor( "pencil", Qt::ArrowCursor ) );
-    }
-    else
+    if ( element.isNull() )
     {
         delete m_drawingEngine;
         m_drawingEngine = 0;
         m_drawingRect = QRect();
         setCursor( Qt::ArrowCursor );
     }
+    else
+    {
+        m_drawingEngine = new SmoothPathEngine( element );
+        setCursor( QCursor( QPixmap( QStringLiteral("pencil") ), Qt::ArrowCursor ) );
+        m_currentDrawingToolElement = element;
+    }
+}
+
+void PresentationWidget::slotAddDrawingToolActions()
+{
+    DrawingToolActions *drawingToolActions = qobject_cast<DrawingToolActions*>(sender());
+    foreach(QAction *action, drawingToolActions->actions()) {
+        action->setEnabled( true );
+        m_topBar->addAction( action );
+        addAction( action );
+    }
 }
 
 void PresentationWidget::clearDrawings()
@@ -1571,7 +1602,7 @@ void PresentationWidget::setScreen( int newScreen )
 {
     const QRect screenGeom = QApplication::desktop()->screenGeometry( newScreen );
     const QSize oldSize = size();
-    // kDebug() << newScreen << "=>" << screenGeom;
+    // qCDebug(OkularUiDebug) << newScreen << "=>" << screenGeom;
     m_screen = newScreen;
     setGeometry( screenGeom );
 
@@ -1617,19 +1648,66 @@ void PresentationWidget::applyNewScreenSize( const QSize & oldSize )
 
 void PresentationWidget::inhibitPowerManagement()
 {
+#ifdef Q_OS_LINUX
     QString reason = i18nc( "Reason for inhibiting the screensaver activation, when the presentation mode is active", "Giving a presentation" );
 
-    // Inhibit screen and sleep
-    // Note: beginSuppressingScreenPowerManagement inhibits DPMS, automatic brightness change and screensaver
-    m_screenInhibitCookie = Solid::PowerManagement::beginSuppressingScreenPowerManagement(reason);
-    m_sleepInhibitCookie = Solid::PowerManagement::beginSuppressingSleep(reason);
+    if (!m_screenInhibitCookie) {
+        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver", "/ScreenSaver",
+                                                              "org.freedesktop.ScreenSaver", "Inhibit");
+        message << QCoreApplication::applicationName();
+        message << reason;
+
+        QDBusPendingReply<uint> reply = QDBusConnection::sessionBus().asyncCall(message);
+        reply.waitForFinished();
+        if (reply.isValid()) {
+            m_screenInhibitCookie = reply.value();
+            qDebug() << "Screen inhibition cookie" << m_screenInhibitCookie;
+        } else {
+            qWarning() << "Unable to inhibit screensaver" << reply.error();
+        }
+    }
+
+    if (!m_sleepInhibitCookie) {
+        QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
+                                                              QStringLiteral("/org/freedesktop/login1"),
+                                                              QStringLiteral("org.freedesktop.login1.Manager"),
+                                                              QStringLiteral("Inhibit")
+                                                              );
+        message << QStringLiteral("sleep");
+        message << QCoreApplication::applicationName();
+        message << reason;
+        message << QStringLiteral("block");
+
+        QDBusPendingReply<QDBusUnixFileDescriptor> reply = QDBusConnection::systemBus().asyncCall(message);
+        reply.waitForFinished();
+        if (reply.isValid()) {
+            m_sleepInhibitCookie = reply.value().fileDescriptor();
+        } else {
+            qWarning() << "Unable to inhibit sleep" << reply.error();
+        }
+    }
+#endif
 }
 
 void PresentationWidget::allowPowerManagement()
 {
-    // Remove cookies
-    Solid::PowerManagement::stopSuppressingScreenPowerManagement(m_screenInhibitCookie);
-    Solid::PowerManagement::stopSuppressingSleep(m_sleepInhibitCookie);
+#ifdef Q_OS_LINUX
+    if (m_sleepInhibitCookie) {
+        ::close(m_sleepInhibitCookie);
+        m_sleepInhibitCookie = 0;
+    }
+
+    if (m_screenInhibitCookie) {
+        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver", "/ScreenSaver",
+                                                              "org.freedesktop.ScreenSaver", "UnInhibit");
+        message << m_screenInhibitCookie;
+
+        QDBusPendingReply<uint> reply = QDBusConnection::sessionBus().asyncCall(message);
+        reply.waitForFinished();
+
+        m_screenInhibitCookie = 0;
+    }
+#endif
 }
 
 void PresentationWidget::showTopBar( bool show )
@@ -2071,8 +2149,13 @@ void PresentationWidget::initTransition( const Okular::PageTransition *transitio
             // randomize the grid
             for ( int i = 0; i < steps; i++ )
             {
+#ifndef Q_OS_WIN
                 int n1 = (int)(steps * drand48());
                 int n2 = (int)(steps * drand48());
+#else
+                int n1 = (int)(steps * (std::rand() / RAND_MAX));
+                int n2 = (int)(steps * (std::rand() / RAND_MAX));
+#endif
                 // swap items if index differs
                 if ( n1 != n2 )
                 {
@@ -2162,8 +2245,13 @@ void PresentationWidget::initTransition( const Okular::PageTransition *transitio
             int randomSteps = steps / 20;
             for ( int i = 0; i < randomSteps; i++ )
             {
+#ifndef Q_OS_WIN
                 int n1 = (int)(steps * drand48());
                 int n2 = (int)(steps * drand48());
+#else
+                int n1 = (int)(steps * (std::rand() / RAND_MAX));
+                int n2 = (int)(steps * (std::rand() / RAND_MAX));
+#endif
                 // swap items if index differs
                 if ( n1 != n2 )
                 {
@@ -2279,6 +2367,8 @@ void PresentationWidget::slotProcessRenditionAction( const Okular::RenditionActi
         case Okular::RenditionAction::Resume:
             vw->play();
             break;
+        default:
+            return;
     };
 }
 
